@@ -2,7 +2,7 @@ use std::cell::RefCell;
 use std::collections::{BTreeMap, BTreeSet};
 use std::error::Error;
 use std::fs;
-use std::io::{ErrorKind, Write};
+use std::io::ErrorKind;
 use std::path::{Path, PathBuf};
 use std::rc::Rc;
 use std::str;
@@ -17,8 +17,8 @@ use crate::utils::{path_to_storage, style};
 use crate::{env::get_tool_config, output::SnapshotPrinter};
 use crate::{
     env::{
-        memoize_snapshot_file, snapshot_update_behavior, OutputBehavior, SnapshotUpdateBehavior,
-        ToolConfig,
+        memoize_snapshot_file, pending_snapshot_path, snapshot_update_behavior, OutputBehavior,
+        SnapshotUpdateBehavior, ToolConfig,
     },
     snapshot::TextSnapshotKind,
 };
@@ -35,14 +35,17 @@ thread_local! {
     static RECORDED_DUPLICATES: RefCell<Vec<BTreeMap<String, Snapshot>>> = RefCell::default()
 }
 
-// This macro is basically eprintln but without being captured and
-// hidden by the test runner.
+// Writes to stderr and also to a warnings file (if INSTA_WARNINGS_FILE is set).
+// The warnings file allows cargo-insta to display warnings after tests complete,
+// since test runners like nextest suppress output from passing tests by default.
 #[macro_export]
 macro_rules! elog {
-    () => (write!(std::io::stderr()).ok());
-    ($($arg:tt)*) => ({
-        writeln!(std::io::stderr(), $($arg)*).ok();
-    })
+    ($($arg:tt)*) => {{
+        use std::io::Write as _;
+        let msg = format!($($arg)*);
+        let _ = writeln!(std::io::stderr(), "{}", msg);
+        $crate::env::memoize_warning(&msg);
+    }};
 }
 #[cfg(feature = "glob")]
 macro_rules! print_or_panic {
@@ -490,15 +493,16 @@ impl<'a> SnapshotAssertionContext<'a> {
         // let's just make sure there are no more pending files lingering
         // around.
         if let Some(ref snapshot_file) = self.snapshot_file {
-            let snapshot_file = snapshot_file.clone().with_extension("snap.new");
-            fs::remove_file(snapshot_file).ok();
+            let target_path = pending_snapshot_path(self.workspace, snapshot_file);
+            let new_file = target_path.with_extension("snap.new");
+            fs::remove_file(new_file).ok();
         }
 
         // and add a null pending snapshot to a pending snapshot file if needed
         if let Some(ref pending_snapshots) = self.pending_snapshots_path {
-            if fs::metadata(pending_snapshots).is_ok() {
-                PendingInlineSnapshot::new(None, None, self.assertion_line)
-                    .save(pending_snapshots)?;
+            let target_path = pending_snapshot_path(self.workspace, pending_snapshots);
+            if fs::metadata(&target_path).is_ok() {
+                PendingInlineSnapshot::new(None, None, self.assertion_line).save(&target_path)?;
             }
         }
         Ok(())
@@ -509,11 +513,17 @@ impl<'a> SnapshotAssertionContext<'a> {
     /// pending snapshot.
     pub fn cleanup_previous_pending_binary_snapshots(&self) -> Result<(), Box<dyn Error>> {
         if let Some(ref path) = self.snapshot_file {
+            // Use pending directory if set
+            let target_path = pending_snapshot_path(self.workspace, path);
+
             // The file name to compare against has to be valid utf-8 as it is generated by this crate
             // out of utf-8 strings.
-            let file_name_prefix = format!("{}.new.", path.file_name().unwrap().to_str().unwrap());
+            let file_name_prefix = format!(
+                "{}.new.",
+                target_path.file_name().unwrap().to_str().unwrap()
+            );
 
-            let read_dir = path.parent().unwrap().read_dir();
+            let read_dir = target_path.parent().unwrap().read_dir();
 
             match read_dir {
                 Err(e) if e.kind() == ErrorKind::NotFound => return Ok(()),
@@ -584,8 +594,9 @@ impl<'a> SnapshotAssertionContext<'a> {
             }
             SnapshotUpdateBehavior::NewFile => {
                 if let Some(ref snapshot_file) = self.snapshot_file {
-                    // File snapshot
-                    let new_path = new_snapshot.save_new(snapshot_file)?;
+                    // File snapshot - use pending directory if set
+                    let target_path = pending_snapshot_path(self.workspace, snapshot_file);
+                    let new_path = new_snapshot.save_new(&target_path)?;
                     if should_print {
                         elog!(
                             "{} {}",
@@ -603,12 +614,15 @@ impl<'a> SnapshotAssertionContext<'a> {
                         );
                     }
                 } else {
+                    // Inline snapshot - use pending directory if set
+                    let pending_path = self.pending_snapshots_path.as_ref().unwrap();
+                    let target_path = pending_snapshot_path(self.workspace, pending_path);
                     PendingInlineSnapshot::new(
                         Some(new_snapshot),
                         self.old_snapshot.clone(),
                         self.assertion_line,
                     )
-                    .save(self.pending_snapshots_path.as_ref().unwrap())?;
+                    .save(&target_path)?;
                 }
             }
             SnapshotUpdateBehavior::NoUpdate => {}
